---
name: All Issues
about: Template for all types of issues
title: ''
labels: ''
assignees: ''

---

Please read the following resources before posting issues:

Common questions:
https://github.com/MIC-DKFZ/nnUNet/blob/master/documentation/common_questions.md

Common Problems and their solutions:
https://github.com/MIC-DKFZ/nnUNet/blob/master/documentation/common_problems_and_solutions.md

Expected epoch times and tips on how to identify bottlenecks:
https://github.com/MIC-DKFZ/nnUNet/blob/master/documentation/expected_epoch_times.md


